==> mstflint_4.17.0+1.orig.tar.gz: mstflint-4.17.0/pldmlib/pldm_component_image.h <==
/*
 * Copyright (c) 2020 Mellanox Technologies Ltd.  All rights reserved.
 *
 * This software is available to you under a choice of one of two
 * licenses.  You may choose to be licensed under the terms of the GNU
 * General Public License (GPL) Version 2, available from the file
 * COPYING in the main directory of this source tree, or the
 * OpenIB.org BSD license below:
 *
 *     Redistribution and use in source and binary forms, with or
 *     without modification, are permitted provided that the following
 *     conditions are met:
 *
 *      - Redistributions of source code must retain the above
 *        copyright notice, this list of conditions and the following
 *        disclaimer.
 *
 *      - Redistributions in binary form must reproduce the above
 *        copyright notice, this list of conditions and the following
 *        disclaimer in the documentation and/or other materials
 *        provided with the distribution.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
 * EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
 * MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 * NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS
 * BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN
 * ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN
 * CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 *
 * pldm_utils.h
 *
 *  Created on: Feb 27, 2019
 *      Author: Samer Deeb
 */

#ifndef _PLDM_COMPONENET_IMAGE_
#define _PLDM_COMPONENET_IMAGE_

class PldmComponenetImage {
public:
    PldmComponenetImage();
    virtual ~PldmComponenetImage();
    bool unpack(PldmBuffer & buff);
    void print(FILE * fp);
    u_int32_t getComponentSize() const { return componentSize; }
    const u_int8_t * getComponentData() const { return componentData; }

private:
    bool readComponentData(PldmBuffer & buff);

    u_int16_t componentClassification;
    u_int16_t componentIdentifier;
    u_int32_t componentComparisonStamp;
    u_int16_t componentOptions;
    u_int16_t requestedComponentActivationMethod;
    u_int32_t componentLocationOffset;
    u_int32_t componentSize;
    u_int8_t componentVersionStringType;
    u_int8_t componentVersionStringLength;
    std::string componentVersionString;

    u_int8_t * componentData;
};

#endif /* _PLDM_COMPONENET_IMAGE_ */

==> mstflint-4.23.0_p1.tar.gz: mstflint-4.23.0-1/pldmlib/pldm_component_image.h <==
/*
 * Copyright (c) 2020-2021 NVIDIA CORPORATION & AFFILIATES. All rights reserved.
 *
 * This software is available to you under a choice of one of two
 * licenses.  You may choose to be licensed under the terms of the GNU
 * General Public License (GPL) Version 2, available from the file
 * COPYING in the main directory of this source tree, or the
 * OpenIB.org BSD license below:
 *
 *     Redistribution and use in source and binary forms, with or
 *     without modification, are permitted provided that the following
 *     conditions are met:
 *
 *      - Redistributions of source code must retain the above
 *        copyright notice, this list of conditions and the following
 *        disclaimer.
 *
 *      - Redistributions in binary form must reproduce the above
 *        copyright notice, this list of conditions and the following
 *        disclaimer in the documentation and/or other materials
 *        provided with the distribution.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
 * EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
 * MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 * NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS
 * BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN
 * ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN
 * CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 *
 * pldm_utils.h
 *
 *  Created on: Feb 27, 2019
 *      Author: Samer Deeb
 */

#ifndef _PLDM_COMPONENET_IMAGE_
#define _PLDM_COMPONENET_IMAGE_

class PldmComponenetImage
{
public:
    PldmComponenetImage();
    virtual ~PldmComponenetImage();
    bool unpack(PldmBuffer& buff);
    void print(FILE* fp);
    u_int32_t getComponentSize() const { return componentSize; }
    const u_int8_t* getComponentData() const { return componentData; }

private:
    bool readComponentData(PldmBuffer& buff);

    u_int16_t componentClassification;
    u_int16_t componentIdentifier;
    u_int32_t componentComparisonStamp;
    u_int16_t componentOptions;
    u_int16_t requestedComponentActivationMethod;
    u_int32_t componentLocationOffset;
    u_int32_t componentSize;
    u_int8_t componentVersionStringType;
    u_int8_t componentVersionStringLength;
    std::string componentVersionString;

    u_int8_t* componentData;
};

#endif /* _PLDM_COMPONENET_IMAGE_ */
